## 0.8.0 (2025-07-12)

### Feat

- Test imports upgraded to the new structure

### Fix

- Version

## 0.7.0 (2025-07-12)

### Feat

- Custom system prompt

### Fix

- GitHub release script now filters semantic version tags only
- Github release workflow

## 0.6.0 (2025-05-29)

### Feat

- Argentic as module
- Environment knowledge tool
- Environment store for coordinate-based RAG

### Fix

- reset version to baseline for proper commitizen operation
- Agent shutdown
- CLI client id
- Entry command arguments parsing
- Precommit testing scripts

## 0.5.0 (2025-05-16)
